pitchtools.PitchObjectSet
=========================

.. inheritance-diagram:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.copy

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.difference

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.intersection

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.isdisjoint

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.issubset

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.issuperset

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.symmetric_difference

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.union

    Inherited from :py:class:`__builtin__.frozenset`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__and__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__cmp__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__contains__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__eq__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__ge__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__gt__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__hash__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__iter__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__le__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__len__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__lt__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__ne__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__or__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__rand__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__repr__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__ror__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__rsub__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__rxor__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__sub__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.PitchObjectSet.PitchObjectSet.PitchObjectSet.__xor__

    Inherited from :py:class:`__builtin__.frozenset`
